# pydress
Directional Relativistic Spectrum Simulator (DRESS), mainly developed for fusion reactions.

## Installation
The package is installed by the following sequence of steps:

- Easier method: Install from PyPI 

```
pip install pydress
```

- Clone git repository and pip install local copy

```
git clone https://github.com/jacob-eri/pydress
cd pydress
pip install -e .
```

## Documentation
A short Jupyter notebook demonstrating the basic capabilities of the package can be found in "/foo/bar/pydress/doc".
